diff --git a/static/js/components/RecipeModal.js b/static/js/components/RecipeModal.js
index 5c81b242..e05e43bc 100644
--- a/static/js/components/RecipeModal.js
+++ b/static/js/components/RecipeModal.js
@@ -451,8 +451,6 @@ class RecipeModal {
lorasListElement.innerHTML = '
No LoRAs associated with this recipe
';
this.recipeLorasSyntax = '';
}
-
- console.log(this.currentRecipe.loras);
// Show the modal
modalManager.showModal('recipeModal');
@@ -951,8 +949,8 @@ class RecipeModal {
let loraSyntaxMatch = inputValue.match(/]+)(?::[^>]+)?>/);
let fileName = loraSyntaxMatch ? loraSyntaxMatch[1] : inputValue.trim();
- // Remove any file extension if present
- fileName = fileName.replace(/\.\w+$/, '');
+ // Remove .safetensors extension if present
+ fileName = fileName.replace(/\.safetensors$/, '');
// Get the deleted lora data
const deletedLora = this.currentRecipe.loras[loraIndex];